@@ -20,6 +20,11 @@
  * THE SOFTWARE.
  */
 
+#ifdef __APPLE__
+#define __AVAILABILITYMACROS__
+#define DEPRECATED_IN_MAC_OS_X_VERSION_10_7_AND_LATER
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
