@@ -33,6 +33,8 @@
 #define WANTDNS
 #include "inet.h"
 
+#include <gio/gio.h>
+
 #include "hexchat.h"
 #include "util.h"
 #include "ignore.h"
@@ -46,6 +48,7 @@
 #include "text.h"
 #include "ctcp.h"
 #include "hexchatc.h"
+#include "chanopt.h"
 
 
 void
@@ -467,7 +470,7 @@ inbound_chanmsg (server *serv, session *sess, char *chan, char *from,
 
 	if (fromme)
 	{
-  		if (prefs.hex_away_auto_unmark && serv->is_away)
+		if (prefs.hex_away_auto_unmark && serv->is_away && !tags_data->timestamp)
 			sess->server->p_set_back (sess->server);
 		EMIT_SIGNAL_TIMESTAMP (XP_TE_UCHANMSG, sess, from, text, nickchar, NULL,
 									  0, tags_data->timestamp);
@@ -581,6 +584,7 @@ inbound_ujoin (server *serv, char *chan, char *nick, char *ip,
 					const message_tags_data *tags_data)
 {
 	session *sess;
+	int found_unused = FALSE;
 
 	/* already joined? probably a bnc */
 	sess = find_channel (serv, chan);
@@ -592,6 +596,7 @@ inbound_ujoin (server *serv, char *chan, char *nick, char *ip,
 		{
 			/* find a "<none>" tab and use that */
 			sess = find_unused_session (serv);
+			found_unused = sess != NULL;
 			if (!sess)
 				/* last resort, open a new tab/window */
 				sess = new_ircwindow (serv, chan, SESS_CHANNEL, 1);
@@ -599,6 +604,13 @@ inbound_ujoin (server *serv, char *chan, char *nick, char *ip,
 	}
 
 	safe_strcpy (sess->channel, chan, CHANLEN);
+	if (found_unused)
+	{
+		chanopt_load (sess);
+		scrollback_load (sess);
+		if (sess->scrollwritten && sess->scrollback_replay_marklast)
+			sess->scrollback_replay_marklast (sess);
+	}
 
 	fe_set_channel (sess);
 	fe_set_title (sess);
@@ -667,8 +679,10 @@ inbound_nameslist (server *serv, char *chan, char *names,
 						 const message_tags_data *tags_data)
 {
 	session *sess;
+	char **name_list;
+	char *host, *nopre_name;
 	char name[NICKLEN];
-	int pos = 0;
+	int i, offset;
 
 	sess = find_channel (serv, chan);
 	if (!sess)
@@ -687,27 +701,37 @@ inbound_nameslist (server *serv, char *chan, char *names,
 		userlist_clear (sess);
 	}
 
-	while (1)
+	name_list = g_strsplit (names, " ", -1);
+	for (i = 0; name_list[i]; i++)
 	{
-		switch (*names)
+		host = NULL;
+		offset = sizeof(name);
+
+		if (name_list[i][0] == 0)
+			continue;
+
+		if (serv->have_uhnames)
 		{
-		case 0:
-			name[pos] = 0;
-			if (pos != 0)
-				userlist_add (sess, name, 0, NULL, NULL, tags_data);
-			return;
-		case ' ':
-			name[pos] = 0;
-			pos = 0;
-			userlist_add (sess, name, 0, NULL, NULL, tags_data);
-			break;
-		default:
-			name[pos] = *names;
-			if (pos < (NICKLEN-1))
-				pos++;
+			offset = 0;
+			nopre_name = name_list[i];
+
+			/* Ignore prefixes so '!' won't cause issues */
+			while (strchr (serv->nick_prefixes, *nopre_name) != NULL)
+			{
+				nopre_name++;
+				offset++;
+			}
+
+			offset += strcspn (nopre_name, "!");
+			if (offset++ < strlen (name_list[i]))
+				host = name_list[i] + offset;
 		}
-		names++;
+
+		g_strlcpy (name, name_list[i], MIN(offset, sizeof(name)));
+
+		userlist_add (sess, name, host, NULL, NULL, tags_data);
 	}
+	g_strfreev (name_list);
 }
 
 void
@@ -754,7 +778,7 @@ inbound_join (server *serv, char *chan, char *user, char *ip, char *account,
 	session *sess = find_channel (serv, chan);
 	if (sess)
 	{
-		EMIT_SIGNAL_TIMESTAMP (XP_TE_JOIN, sess, user, chan, ip, NULL, 0,
+		EMIT_SIGNAL_TIMESTAMP (XP_TE_JOIN, sess, user, chan, ip, account, 0,
 									  tags_data->timestamp);
 		userlist_add (sess, user, ip, account, realname, tags_data);
 	}
@@ -878,8 +902,8 @@ inbound_ping_reply (session *sess, char *timestring, char *from,
 	if (lag)
 	{
 		sess->server->lag_sent = 0;
-		sess->server->lag = dif / 1000;
-		fe_set_lag (sess->server, dif / 100000);
+		sess->server->lag = dif;
+		fe_set_lag (sess->server, dif);
 		return;
 	}
 
@@ -892,7 +916,7 @@ inbound_ping_reply (session *sess, char *timestring, char *from,
 										  tags_data->timestamp);
 	} else
 	{
-		snprintf (outbuf, sizeof (outbuf), "%ld.%ld%ld", dif / 1000000, (dif / 100000) % 10, dif % 10);
+		snprintf (outbuf, sizeof (outbuf), "%ld.%03ld", dif / 1000, dif % 1000);
 		EMIT_SIGNAL_TIMESTAMP (XP_TE_PINGREP, sess, from, outbuf, NULL, NULL, 0,
 									  tags_data->timestamp);
 	}
@@ -924,19 +948,8 @@ inbound_notice (server *serv, char *to, char *nick, char *msg, char *ip, int id,
 	if (is_channel (serv, ptr))
 		sess = find_channel (serv, ptr);
 
-	if (!sess && ptr[0] == '@')
-	{
-		ptr++;
-		sess = find_channel (serv, ptr);
-	}
-
-	if (!sess && ptr[0] == '%')
-	{
-		ptr++;
-		sess = find_channel (serv, ptr);
-	}
-
-	if (!sess && ptr[0] == '+')
+	/* /notice [mode-prefix]#channel should end up in that channel */
+	if (!sess && strchr(serv->nick_prefixes, ptr[0]) != NULL)
 	{
 		ptr++;
 		sess = find_channel (serv, ptr);
@@ -1258,20 +1271,74 @@ inbound_next_nick (session *sess, char *nick, int error,
 	}
 }
 
+
+static void
+dns_addr_callback (GObject *obj, GAsyncResult *result, gpointer user_data)
+{
+	GResolver *resolver = G_RESOLVER(obj);
+	session *sess = (session*)user_data;
+	gchar *addr;
+
+	g_return_if_fail (is_session(sess));
+
+	addr = g_resolver_lookup_by_address_finish (resolver, result, NULL);
+	if (addr)
+		PrintTextf (sess, _("Resolved to %s"), addr);
+	else
+		PrintText (sess, _("Not found"));
+}
+
+static void
+dns_name_callback (GObject *obj, GAsyncResult *result, gpointer user_data)
+{
+	GResolver *resolver = G_RESOLVER(obj);
+	session *sess = (session*)user_data;
+	GList* addrs;
+	gchar* addr;
+	GList* list;
+
+	g_return_if_fail (is_session (sess));
+
+	addrs = g_resolver_lookup_by_name_finish (resolver, result, NULL);
+	if (addrs)
+	{
+		PrintText (sess, _("Resolved to:"));
+
+		for (list = g_list_first (addrs); list; list = g_list_next (list))
+		{
+			addr = g_inet_address_to_string (list->data);
+			PrintTextf (sess, "    %s", addr);
+		}
+
+		g_resolver_free_addresses (addrs);
+	}
+	else
+		PrintText (sess, _("Not found"));
+}
+
 void
 do_dns (session *sess, char *nick, char *host,
-		  const message_tags_data *tags_data)
+		const message_tags_data *tags_data)
 {
+	GResolver *res = g_resolver_get_default ();
+	GInetAddress *addr;
 	char *po;
-	char tbuf[1024];
 
 	po = strrchr (host, '@');
 	if (po)
 		host = po + 1;
-	EMIT_SIGNAL_TIMESTAMP (XP_TE_RESOLVINGUSER, sess, nick, host, NULL, NULL, 0,
-								  tags_data->timestamp);
-	snprintf (tbuf, sizeof (tbuf), "exec -d %s %s", prefs.hex_dnsprogram, host);
-	handle_command (sess, tbuf, FALSE);
+
+	if (nick)
+		EMIT_SIGNAL_TIMESTAMP (XP_TE_RESOLVINGUSER, sess, nick, host, NULL, NULL, 0,
+								tags_data->timestamp);
+
+	PrintTextf (sess, _("Looking up %s..."), host);
+
+	addr = g_inet_address_new_from_string (host);
+	if (addr)
+		g_resolver_lookup_by_address_async (res, addr, NULL, dns_addr_callback, sess);
+	else
+		g_resolver_lookup_by_name_async (res, host, NULL, dns_name_callback, sess);
 }
 
 static void
@@ -1288,6 +1355,8 @@ set_default_modes (server *serv)
 		strcat (modes, "s");
 	if (prefs.hex_irc_invisible)
 		strcat (modes, "i");
+	if (prefs.hex_irc_hidehost)
+		strcat (modes, "x");
 
 	if (modes[1] != '\0')
 	{
@@ -1425,10 +1494,15 @@ inbound_banlist (session *sess, time_t stamp, char *chan, char *mask,
 	server *serv = sess->server;
 	char *nl;
 
-	if ((nl = strchr (time_str, '\n')))
-		*nl = 0;
-	if (stamp == 0)
+	if (stamp <= 0)
+	{
 		time_str = "";
+	}
+	else
+	{
+		if ((nl = strchr (time_str, '\n')))
+			*nl = 0;
+	}
 
 	sess = find_channel (serv, chan);
 	if (!sess)
@@ -1594,6 +1668,11 @@ inbound_cap_ack (server *serv, char *nick, char *extensions,
 		serv->have_extjoin = TRUE;
 	}
 
+	if (strstr (extensions, "userhost-in-names") != NULL)
+	{
+		serv->have_uhnames = TRUE;
+	}
+
 	if (strstr (extensions, "server-time") != NULL)
 	{
 		serv->have_server_time = TRUE;
@@ -1671,6 +1750,11 @@ inbound_cap_ls (server *serv, char *nick, char *extensions_str,
 			strcat (buffer, "extended-join ");
 			want_cap = 1;
 		}
+		if (!strcmp (extension, "userhost-in-names"))
+		{
+			strcat (buffer, "userhost-in-names ");
+			want_cap = 1;
+		}
 
 		/* bouncers can prefix a name space to the extension so we should use.
 		 * znc <= 1.0 uses "znc.in/server-time" and newer use "znc.in/server-time-iso".
@@ -1678,15 +1762,18 @@ inbound_cap_ls (server *serv, char *nick, char *extensions_str,
 		if (!strcmp (extension, "znc.in/server-time-iso"))
 		{
 			strcat (buffer, "znc.in/server-time-iso ");
+			want_cap = 1;
 		}
 		if (!strcmp (extension, "znc.in/server-time"))
 		{
 			strcat (buffer, "znc.in/server-time ");
+			want_cap = 1;
 		}
 		if (prefs.hex_irc_cap_server_time
 			 && !strcmp (extension, "server-time"))
 		{
 			strcat (buffer, "server-time ");
+			want_cap = 1;
 		}
 		
 		/* if the SASL password is set AND auth mode is set to SASL, request SASL auth */
@@ -1708,7 +1795,7 @@ inbound_cap_ls (server *serv, char *nick, char *extensions_str,
 		EMIT_SIGNAL_TIMESTAMP (XP_TE_CAPREQ, serv->server_session,
 									  buffer + 9, NULL, NULL, NULL, 0,
 									  tags_data->timestamp);
-		tcp_sendf (serv, "%s\r\n", buffer);
+		tcp_sendf (serv, "%s\r\n", g_strchomp (buffer));
 	}
 	if (!want_sasl)
 	{
@@ -1741,14 +1828,50 @@ static const char *sasl_mechanisms[] =
 	"EXTERNAL"
 };
 
+void
+inbound_sasl_supportedmechs (server *serv, char *list)
+{
+	int i;
+
+	if (serv->sasl_mech != MECH_EXTERNAL)
+	{
+		/* Use most secure one supported */
+		for (i = MECH_AES; i >= MECH_PLAIN; i--)
+		{
+			if (strstr (list, sasl_mechanisms[i]) != NULL)
+			{
+				serv->sasl_mech = i;
+				serv->retry_sasl = TRUE;
+				tcp_sendf (serv, "AUTHENTICATE %s\r\n", sasl_mechanisms[i]);
+				return;
+			}
+		}
+	}
+
+	/* Abort, none supported */
+	serv->sent_saslauth = TRUE;
+	tcp_sendf (serv, "AUTHENTICATE *\r\n");
+	return;
+}
+
 void
 inbound_sasl_authenticate (server *serv, char *data)
 {
+		ircnet *net = (ircnet*)serv->network;
 		char *user, *pass = NULL;
 		const char *mech = sasl_mechanisms[serv->sasl_mech];
 
-		user = (((ircnet*)serv->network)->user)
-				? (((ircnet*)serv->network)->user) : prefs.hex_irc_user_name;
+		/* Got a list of supported mechanisms from inspircd */
+		if (strchr (data, ',') != NULL)
+		{
+			inbound_sasl_supportedmechs (serv, data);
+			return;
+		}
+
+		if (net->user && !(net->flags & FLAG_USE_GLOBAL))
+			user = net->user;
+		else
+			user = prefs.hex_irc_user_name;
 
 		switch (serv->sasl_mech)
 		{
@@ -1788,6 +1911,9 @@ inbound_sasl_authenticate (server *serv, char *data)
 int
 inbound_sasl_error (server *serv)
 {
+	if (serv->retry_sasl && !serv->sent_saslauth)
+		return 1;
+
 	/* If server sent 904 before we sent password,
 		* mech not support so fallback to next mech */
 	if (!serv->sent_saslauth && serv->sasl_mech != MECH_EXTERNAL && serv->sasl_mech != MECH_PLAIN)
