@@ -75,16 +75,14 @@ chanlist_match (server *serv, const char *str)
 	switch (serv->gui->chanlist_search_type)
 	{
 	case 1:
-		return match (GTK_ENTRY (serv->gui->chanlist_wild)->text, str);
-#ifndef WIN32
+		return match (gtk_entry_get_text (GTK_ENTRY (serv->gui->chanlist_wild)), str);
 	case 2:
 		if (!serv->gui->have_regex)
 			return 0;
-		/* regex returns 0 if it's a match: */
-		return !regexec (&serv->gui->chanlist_match_regex, str, 1, NULL, REG_NOTBOL);
-#endif
+
+		return g_regex_match (serv->gui->chanlist_match_regex, str, 0, NULL);
 	default:	/* case 0: */
-		return nocasestrstr (str, GTK_ENTRY (serv->gui->chanlist_wild)->text) ? 1 : 0;
+		return nocasestrstr (str, gtk_entry_get_text (GTK_ENTRY (serv->gui->chanlist_wild))) ? 1 : 0;
 	}
 }
 
@@ -227,7 +225,7 @@ chanlist_place_row_in_gui (server *serv, chanlistrow *next_row, gboolean force)
 		return;
 	}
 
-	if (GTK_ENTRY (serv->gui->chanlist_wild)->text[0])
+	if (gtk_entry_get_text (GTK_ENTRY (serv->gui->chanlist_wild))[0])
 	{
 		/* Check what the user wants to match. If both buttons or _neither_
 		 * button is checked, look for match in both by default. 
@@ -406,30 +404,32 @@ chanlist_search_pressed (GtkButton * button, server *serv)
 static void
 chanlist_find_cb (GtkWidget * wid, server *serv)
 {
-#ifndef WIN32
+	const char *pattern = gtk_entry_get_text (GTK_ENTRY (wid));
+
 	/* recompile the regular expression. */
 	if (serv->gui->have_regex)
 	{
 		serv->gui->have_regex = 0;
-		regfree (&serv->gui->chanlist_match_regex);
+		g_regex_unref (serv->gui->chanlist_match_regex);
 	}
 
-	if (regcomp (&serv->gui->chanlist_match_regex, GTK_ENTRY (wid)->text,
-					 REG_ICASE | REG_EXTENDED | REG_NOSUB) == 0)
+	serv->gui->chanlist_match_regex = g_regex_new (pattern, G_REGEX_CASELESS | G_REGEX_EXTENDED,
+												G_REGEX_MATCH_NOTBOL, NULL);
+
+	if (serv->gui->chanlist_match_regex)
 		serv->gui->have_regex = 1;
-#endif
 }
 
 static void
 chanlist_match_channel_button_toggled (GtkWidget * wid, server *serv)
 {
-	serv->gui->chanlist_match_wants_channel = GTK_TOGGLE_BUTTON (wid)->active;
+	serv->gui->chanlist_match_wants_channel = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wid));
 }
 
 static void
 chanlist_match_topic_button_toggled (GtkWidget * wid, server *serv)
 {
-	serv->gui->chanlist_match_wants_topic = GTK_TOGGLE_BUTTON (wid)->active;
+	serv->gui->chanlist_match_wants_topic = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wid));
 }
 
 static char *
@@ -519,7 +519,7 @@ chanlist_save (GtkWidget * wid, server *serv)
 static gboolean
 chanlist_flash (server *serv)
 {
-	if (serv->gui->chanlist_refresh->state != GTK_STATE_ACTIVE)
+	if (gtk_widget_get_state (serv->gui->chanlist_refresh) != GTK_STATE_ACTIVE)
 		gtk_widget_set_state (serv->gui->chanlist_refresh, GTK_STATE_ACTIVE);
 	else
 		gtk_widget_set_state (serv->gui->chanlist_refresh, GTK_STATE_PRELIGHT);
@@ -615,7 +615,7 @@ chanlist_button_cb (GtkTreeView *tree, GdkEventButton *event, server *serv)
 
 	menu = gtk_menu_new ();
 	if (event->window)
-		gtk_menu_set_screen (GTK_MENU (menu), gdk_drawable_get_screen (event->window));
+		gtk_menu_set_screen (GTK_MENU (menu), gdk_window_get_screen (event->window));
 	g_object_ref (menu);
 	g_object_ref_sink (menu);
 	g_object_unref (menu);
@@ -655,13 +655,11 @@ chanlist_destroy_widget (GtkWidget *wid, server *serv)
 		serv->gui->chanlist_tag = 0;
 	}
 
-#ifndef WIN32
 	if (serv->gui->have_regex)
 	{
-		regfree (&serv->gui->chanlist_match_regex);
+		g_regex_unref (serv->gui->chanlist_match_regex);
 		serv->gui->have_regex = 0;
 	}
-#endif
 }
 
 static void
@@ -688,11 +686,16 @@ chanlist_add_column (GtkWidget *tree, int textcol, int size, char *title, gboole
 	col = gtk_tree_view_get_column (GTK_TREE_VIEW (tree), textcol);
 	gtk_tree_view_column_set_sort_column_id (col, textcol);
 	gtk_tree_view_column_set_resizable (col, TRUE);
-	if (textcol != COL_TOPIC)
+	if (textcol == COL_CHANNEL)
 	{
 		gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
 		gtk_tree_view_column_set_fixed_width (col, size);
 	}
+	else if (textcol == COL_USERS)
+	{
+		gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+		gtk_tree_view_column_set_resizable (col, FALSE);
+	}
 }
 
 static void
@@ -762,7 +765,7 @@ chanlist_opengui (server *serv, int do_refresh)
 
 	store = (GtkListStore *) custom_list_new();
 	view = gtkutil_treeview_new (vbox, GTK_TREE_MODEL (store), NULL, -1);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (view->parent),
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (gtk_widget_get_parent (view)),
 													 GTK_SHADOW_IN);
 	serv->gui->chanlist_list = view;
 
@@ -870,16 +873,15 @@ chanlist_opengui (server *serv, int do_refresh)
 
 	wid = gtk_check_button_new_with_label (_("Channel name"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid), TRUE);
-	gtk_signal_connect (GTK_OBJECT (wid), "toggled",
-							  GTK_SIGNAL_FUNC
-							  (chanlist_match_channel_button_toggled), serv);
+	g_signal_connect (G_OBJECT (wid), "toggled",
+							  G_CALLBACK(chanlist_match_channel_button_toggled), serv);
 	gtk_box_pack_start (GTK_BOX (hbox), wid, 0, 0, 0);
 	gtk_widget_show (wid);
 
 	wid = gtk_check_button_new_with_label (_("Topic"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid), TRUE);
-	gtk_signal_connect (GTK_OBJECT (wid), "toggled",
-							  GTK_SIGNAL_FUNC (chanlist_match_topic_button_toggled),
+	g_signal_connect (G_OBJECT (wid), "toggled",
+							  G_CALLBACK (chanlist_match_topic_button_toggled),
 							  serv);
 	gtk_box_pack_start (GTK_BOX (hbox), wid, 0, 0, 0);
 	gtk_widget_show (wid);
@@ -895,12 +897,10 @@ chanlist_opengui (server *serv, int do_refresh)
 							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 	gtk_widget_show (wid);
 
-	wid = gtk_combo_box_new_text ();
-	gtk_combo_box_append_text (GTK_COMBO_BOX (wid), _("Simple Search"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (wid), _("Pattern Match (Wildcards)"));
-#ifndef WIN32
-	gtk_combo_box_append_text (GTK_COMBO_BOX (wid), _("Regular Expression"));
-#endif
+	wid = gtk_combo_box_text_new ();
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (wid), _("Simple Search"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (wid), _("Pattern Match (Wildcards)"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (wid), _("Regular Expression"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (wid), serv->gui->chanlist_search_type);
 	gtk_table_attach (GTK_TABLE (table), wid, 1, 2, 1, 2,
 							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
@@ -916,11 +916,12 @@ chanlist_opengui (server *serv, int do_refresh)
 							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 	gtk_widget_show (wid);
 
-	wid = gtk_entry_new_with_max_length (255);
-	gtk_signal_connect (GTK_OBJECT (wid), "changed",
-							  GTK_SIGNAL_FUNC (chanlist_find_cb), serv);
-	gtk_signal_connect (GTK_OBJECT (wid), "activate",
-							  GTK_SIGNAL_FUNC (chanlist_search_pressed),
+	wid = gtk_entry_new ();
+	gtk_entry_set_max_length (GTK_ENTRY(wid), 255);
+	g_signal_connect (G_OBJECT (wid), "changed",
+							  G_CALLBACK (chanlist_find_cb), serv);
+	g_signal_connect (G_OBJECT (wid), "activate",
+							  G_CALLBACK (chanlist_search_pressed),
 							  (gpointer) serv);
 	gtk_table_attach (GTK_TABLE (table), wid, 1, 2, 0, 1,
 							GTK_EXPAND | GTK_FILL, 0, 0, 0);
