@@ -67,18 +67,19 @@ cv_tabs_sizealloc (GtkWidget *widget, GtkAllocation *allocation, chanview *cv)
 	gint viewport_size;
 
 	inner = ((tabview *)cv)->inner;
+	GdkWindow *parent_win = gtk_widget_get_window (gtk_widget_get_parent (inner));
 
 	if (cv->vertical)
 	{
-		adj = gtk_viewport_get_vadjustment (GTK_VIEWPORT (inner->parent));
-		gdk_window_get_geometry (inner->parent->window, 0, 0, 0, &viewport_size, 0);
+		adj = gtk_viewport_get_vadjustment (GTK_VIEWPORT (gtk_widget_get_parent (inner)));
+		gdk_window_get_geometry (parent_win, 0, 0, 0, &viewport_size, 0);
 	} else
 	{
-		adj = gtk_viewport_get_hadjustment (GTK_VIEWPORT (inner->parent));
-		gdk_window_get_geometry (inner->parent->window, 0, 0, &viewport_size, 0, 0);
+		adj = gtk_viewport_get_hadjustment (GTK_VIEWPORT (gtk_widget_get_parent (inner)));
+		gdk_window_get_geometry (parent_win, 0, 0, &viewport_size, 0, 0);
 	}
 
-	if (adj->upper <= viewport_size)
+	if (gtk_adjustment_get_upper (adj) <= viewport_size)
 	{
 		gtk_widget_hide (((tabview *)cv)->b1);
 		gtk_widget_hide (((tabview *)cv)->b2);
@@ -97,30 +98,32 @@ tab_search_offset (GtkWidget *inner, gint start_offset,
 	GList *tabs;
 	GtkWidget *box;
 	GtkWidget *button;
+	GtkAllocation allocation;
 	gint found;
 
-	boxes = GTK_BOX (inner)->children;
+	boxes = gtk_container_get_children (GTK_CONTAINER (inner));
 	if (!forward && boxes)
 		boxes = g_list_last (boxes);
 
 	while (boxes)
 	{
-		box = ((GtkBoxChild *)boxes->data)->widget;
+		box = (GtkWidget *)boxes->data;
 		boxes = (forward ? boxes->next : boxes->prev);
 
-		tabs = GTK_BOX (box)->children;
+		tabs = gtk_container_get_children (GTK_CONTAINER (box));
 		if (!forward && tabs)
 			tabs = g_list_last (tabs);
 
 		while (tabs)
 		{
-			button = ((GtkBoxChild *)tabs->data)->widget;
+			button = (GtkWidget *)tabs->data;
 			tabs = (forward ? tabs->next : tabs->prev);
 
 			if (!GTK_IS_TOGGLE_BUTTON (button))
 				continue;
 
-			found = (vertical ? button->allocation.y : button->allocation.x);
+			gtk_widget_get_allocation (button, &allocation);
+			found = (vertical ? allocation.y : allocation.x);
 			if ((forward && found > start_offset) ||
 				(!forward && found < start_offset))
 				return found;
@@ -137,30 +140,32 @@ tab_scroll_left_up_clicked (GtkWidget *widget, chanview *cv)
 	gint viewport_size;
 	gfloat new_value;
 	GtkWidget *inner;
+	GdkWindow *parent_win;
 	gfloat i;
 
 	inner = ((tabview *)cv)->inner;
+	parent_win = gtk_widget_get_window (gtk_widget_get_parent (inner));
 
 	if (cv->vertical)
 	{
-		adj = gtk_viewport_get_vadjustment (GTK_VIEWPORT (inner->parent));
-		gdk_window_get_geometry (inner->parent->window, 0, 0, 0, &viewport_size, 0);
+		adj = gtk_viewport_get_vadjustment (GTK_VIEWPORT (gtk_widget_get_parent(inner)));
+		gdk_window_get_geometry (parent_win, 0, 0, 0, &viewport_size, 0);
 	} else
 	{
-		adj = gtk_viewport_get_hadjustment (GTK_VIEWPORT (inner->parent));
-		gdk_window_get_geometry (inner->parent->window, 0, 0, &viewport_size, 0, 0);
+		adj = gtk_viewport_get_hadjustment (GTK_VIEWPORT (gtk_widget_get_parent(inner)));
+		gdk_window_get_geometry (parent_win, 0, 0, &viewport_size, 0, 0);
 	}
 
-	new_value = tab_search_offset (inner, adj->value, 0, cv->vertical);
+	new_value = tab_search_offset (inner, gtk_adjustment_get_value (adj), 0, cv->vertical);
 
-	if (new_value + viewport_size > adj->upper)
-		new_value = adj->upper - viewport_size;
+	if (new_value + viewport_size > gtk_adjustment_get_upper (adj))
+		new_value = gtk_adjustment_get_upper (adj) - viewport_size;
 
 	if (!tab_left_is_moving)
 	{
 		tab_left_is_moving = 1;
 
-		for (i = adj->value; ((i > new_value) && (tab_left_is_moving)); i -= 0.1)
+		for (i = gtk_adjustment_get_value (adj); ((i > new_value) && (tab_left_is_moving)); i -= 0.1)
 		{
 			gtk_adjustment_set_value (adj, i);
 			while (g_main_context_pending (NULL))
@@ -184,30 +189,32 @@ tab_scroll_right_down_clicked (GtkWidget *widget, chanview *cv)
 	gint viewport_size;
 	gfloat new_value;
 	GtkWidget *inner;
+	GdkWindow *parent_win;
 	gfloat i;
 
 	inner = ((tabview *)cv)->inner;
+	parent_win = gtk_widget_get_window (gtk_widget_get_parent (inner));
 
 	if (cv->vertical)
 	{
-		adj = gtk_viewport_get_vadjustment (GTK_VIEWPORT (inner->parent));
-		gdk_window_get_geometry (inner->parent->window, 0, 0, 0, &viewport_size, 0);
+		adj = gtk_viewport_get_vadjustment (GTK_VIEWPORT (gtk_widget_get_parent(inner)));
+		gdk_window_get_geometry (parent_win, 0, 0, 0, &viewport_size, 0);
 	} else
 	{
-		adj = gtk_viewport_get_hadjustment (GTK_VIEWPORT (inner->parent));
-		gdk_window_get_geometry (inner->parent->window, 0, 0, &viewport_size, 0, 0);
+		adj = gtk_viewport_get_hadjustment (GTK_VIEWPORT (gtk_widget_get_parent(inner)));
+		gdk_window_get_geometry (parent_win, 0, 0, &viewport_size, 0, 0);
 	}
 
-	new_value = tab_search_offset (inner, adj->value, 1, cv->vertical);
+	new_value = tab_search_offset (inner, gtk_adjustment_get_value (adj), 1, cv->vertical);
 
-	if (new_value == 0 || new_value + viewport_size > adj->upper)
-		new_value = adj->upper - viewport_size;
+	if (new_value == 0 || new_value + viewport_size > gtk_adjustment_get_upper (adj))
+		new_value = gtk_adjustment_get_upper (adj) - viewport_size;
 
 	if (!tab_right_is_moving)
 	{
 		tab_right_is_moving = 1;
 
-		for (i = adj->value; ((i < new_value) && (tab_right_is_moving)); i += 0.1)
+		for (i = gtk_adjustment_get_value (adj); ((i < new_value) && (tab_right_is_moving)); i += 0.1)
 		{
 			gtk_adjustment_set_value (adj, i);
 			while (g_main_context_pending (NULL))
@@ -227,11 +234,21 @@ tab_scroll_right_down_clicked (GtkWidget *widget, chanview *cv)
 static gboolean
 tab_scroll_cb (GtkWidget *widget, GdkEventScroll *event, gpointer cv)
 {
-	/* mouse wheel scrolling */
-	if (event->direction == GDK_SCROLL_UP)
-		tab_scroll_left_up_clicked (widget, cv);
-	else if (event->direction == GDK_SCROLL_DOWN)
-		tab_scroll_right_down_clicked (widget, cv);
+	if (prefs.hex_gui_tab_scrollchans)
+	{
+		if (event->direction == GDK_SCROLL_DOWN)
+			mg_switch_page (1, 1);
+		else if (event->direction == GDK_SCROLL_UP)
+			mg_switch_page (1, -1);
+	}
+	else
+	{
+		/* mouse wheel scrolling */
+		if (event->direction == GDK_SCROLL_UP)
+			tab_scroll_left_up_clicked (widget, cv);
+		else if (event->direction == GDK_SCROLL_DOWN)
+			tab_scroll_right_down_clicked (widget, cv);
+	}
 
 	return FALSE;
 }
@@ -329,7 +346,7 @@ cv_tabs_init (chanview *cv)
 	button = gtkutil_button (outer, GTK_STOCK_CLOSE, NULL, cv_tabs_xclick_cb,
 									 cv, 0);
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
-	GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (button, FALSE);
 
 	gtk_container_add (GTK_CONTAINER (cv->box), outer);
 }
@@ -343,7 +360,7 @@ static void
 tab_add_sorted (chanview *cv, GtkWidget *box, GtkWidget *tab, chan *ch)
 {
 	GList *list;
-	GtkBoxChild *child;
+	GtkWidget *child;
 	int i = 0;
 	void *b;
 
@@ -360,18 +377,18 @@ tab_add_sorted (chanview *cv, GtkWidget *box, GtkWidget *tab, chan *ch)
 	/* userdata, passed to mg_tabs_compare() */
 	b = ch->userdata;
 
-	list = GTK_BOX (box)->children;
+	list = gtk_container_get_children (GTK_CONTAINER (box));
 	while (list)
 	{
 		child = list->data;
-		if (!GTK_IS_SEPARATOR (child->widget))
+		if (!GTK_IS_SEPARATOR (child))
 		{
-			void *a = g_object_get_data (G_OBJECT (child->widget), "u");
+			void *a = g_object_get_data (G_OBJECT (child), "u");
 
 			if (ch->tag == 0 && cv->cb_compare (a, b) > 0)
 			{
 				gtk_box_pack_start (GTK_BOX (box), tab, 0, 0, 0);
-				gtk_box_reorder_child (GTK_BOX (box), tab, i);
+				gtk_box_reorder_child (GTK_BOX (box), tab, ++i);
 				gtk_widget_show (tab);
 				return;
 			}
@@ -393,23 +410,23 @@ cv_tabs_prune (chanview *cv)
 {
 	GList *boxes, *children;
 	GtkWidget *box, *inner;
-	GtkBoxChild *child;
+	GtkWidget *child;
 	int empty;
 
 	inner = ((tabview *)cv)->inner;
-	boxes = GTK_BOX (inner)->children;
+	boxes = gtk_container_get_children (GTK_CONTAINER (inner));
 	while (boxes)
 	{
 		child = boxes->data;
-		box = child->widget;
+		box = child;
 		boxes = boxes->next;
 
 		/* check if the box is empty (except a vseperator) */
 		empty = TRUE;
-		children = GTK_BOX (box)->children;
+		children = gtk_container_get_children (GTK_CONTAINER (box));
 		while (children)
 		{
-			if (!GTK_IS_SEPARATOR (((GtkBoxChild *)children->data)->widget))
+			if (!GTK_IS_SEPARATOR ((GtkWidget *)children->data))
 			{
 				empty = FALSE;
 				break;
@@ -427,21 +444,21 @@ tab_add_real (chanview *cv, GtkWidget *tab, chan *ch)
 {
 	GList *boxes, *children;
 	GtkWidget *sep, *box, *inner;
-	GtkBoxChild *child;
+	GtkWidget *child;
 	int empty;
 
 	inner = ((tabview *)cv)->inner;
 	/* see if a family for this tab already exists */
-	boxes = GTK_BOX (inner)->children;
+	boxes = gtk_container_get_children (GTK_CONTAINER (inner));
 	while (boxes)
 	{
 		child = boxes->data;
-		box = child->widget;
+		box = child;
 
 		if (g_object_get_data (G_OBJECT (box), "f") == ch->family)
 		{
 			tab_add_sorted (cv, box, tab, ch);
-			gtk_widget_queue_resize (inner->parent);
+			gtk_widget_queue_resize (gtk_widget_get_parent(inner));
 			return;
 		}
 
@@ -449,10 +466,10 @@ tab_add_real (chanview *cv, GtkWidget *tab, chan *ch)
 
 		/* check if the box is empty (except a vseperator) */
 		empty = TRUE;
-		children = GTK_BOX (box)->children;
+		children = gtk_container_get_children (GTK_CONTAINER (box));
 		while (children)
 		{
-			if (!GTK_IS_SEPARATOR (((GtkBoxChild *)children->data)->widget))
+			if (!GTK_IS_SEPARATOR ((GtkWidget *)children->data))
 			{
 				empty = FALSE;
 				break;
@@ -484,7 +501,7 @@ tab_add_real (chanview *cv, GtkWidget *tab, chan *ch)
 	gtk_box_pack_start (GTK_BOX (box), tab, 0, 0, 0);
 	gtk_widget_show (tab);
 	gtk_widget_show (box);
-	gtk_widget_queue_resize (inner->parent);
+	gtk_widget_queue_resize (gtk_widget_get_parent(inner));
 }
 
 static gboolean
@@ -590,25 +607,25 @@ tab_group_for_each_tab (chanview *cv,
 {
 	GList *tabs;
 	GList *boxes;
-	GtkBoxChild *child;
+	GtkWidget *child;
 	GtkBox *innerbox;
 	int i;
 
 	innerbox = (GtkBox *) ((tabview *)cv)->inner;
-	boxes = innerbox->children;
+	boxes = gtk_container_get_children (GTK_CONTAINER (innerbox));
 	i = 0;
 	while (boxes)
 	{
 		child = boxes->data;
-		tabs = GTK_BOX (child->widget)->children;
+		tabs = gtk_container_get_children (GTK_CONTAINER (child));
 
 		while (tabs)
 		{
 			child = tabs->data;
 
-			if (!GTK_IS_SEPARATOR (child->widget))
+			if (!GTK_IS_SEPARATOR (child))
 			{
-				if (callback (child->widget, i, usernum) != -1)
+				if (callback (child, i, usernum) != -1)
 					return i;
 				i++;
 			}
@@ -624,7 +641,7 @@ tab_group_for_each_tab (chanview *cv,
 static int
 tab_check_focus_cb (GtkWidget *tab, int num, int unused)
 {
-	if (GTK_TOGGLE_BUTTON (tab)->active)
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (tab)))
 		return num;
 
 	return -1;
@@ -705,19 +722,24 @@ cv_tabs_remove (chan *ch)
 static void
 cv_tabs_move (chan *ch, int delta)
 {
-	int i, pos = 0;
+	int i = 0;
+	int pos = 0;
 	GList *list;
-	GtkWidget *parent = ((GtkWidget *)ch->impl)->parent;
+	GtkWidget *parent = gtk_widget_get_parent(GTK_WIDGET (ch->impl));
 
-	i = 0;
-	for (list = GTK_BOX (parent)->children; list; list = list->next)
+	for (list = gtk_container_get_children (GTK_CONTAINER (parent)); list; list = list->next)
 	{
-		GtkBoxChild *child_entry;
+		GtkWidget *child_entry;
 
 		child_entry = list->data;
-		if (child_entry->widget == ch->impl)
+		if (child_entry == ch->impl)
 			pos = i;
-		i++;
+
+		/* keep separator at end to not throw off our count */
+		if (GTK_IS_SEPARATOR (child_entry))
+			gtk_box_reorder_child (GTK_BOX (parent), child_entry, -1);
+		else
+			i++;
 	}
 
 	pos = (pos - delta) % i;
@@ -733,23 +755,23 @@ cv_tabs_move_family (chan *ch, int delta)
 
 	/* find position of tab's family */
 	i = 0;
-	for (list = GTK_BOX (((tabview *)ch->cv)->inner)->children; list; list = list->next)
+	for (list = gtk_container_get_children (GTK_CONTAINER (((tabview *)ch->cv)->inner)); list; list = list->next)
 	{
-		GtkBoxChild *child_entry;
+		GtkWidget *child_entry;
 		void *fam;
 
 		child_entry = list->data;
-		fam = g_object_get_data (G_OBJECT (child_entry->widget), "f");
+		fam = g_object_get_data (G_OBJECT (child_entry), "f");
 		if (fam == ch->family)
 		{
-			box = child_entry->widget;
+			box = child_entry;
 			pos = i;
 		}
 		i++;
 	}
 
 	pos = (pos - delta) % i;
-	gtk_box_reorder_child (GTK_BOX (box->parent), box, pos);
+	gtk_box_reorder_child (GTK_BOX (gtk_widget_get_parent(box)), box, pos);
 }
 
 static void
@@ -762,7 +784,7 @@ cv_tabs_cleanup (chanview *cv)
 static void
 cv_tabs_set_color (chan *ch, PangoAttrList *list)
 {
-	gtk_label_set_attributes (GTK_LABEL (GTK_BIN (ch->impl)->child), list);
+	gtk_label_set_attributes (GTK_LABEL (gtk_bin_get_child (GTK_BIN (ch->impl))), list);
 }
 
 static void
@@ -771,16 +793,16 @@ cv_tabs_rename (chan *ch, char *name)
 	PangoAttrList *attr;
 	GtkWidget *tab = ch->impl;
 
-	attr = gtk_label_get_attributes (GTK_LABEL (GTK_BIN (tab)->child));
+	attr = gtk_label_get_attributes (GTK_LABEL (gtk_bin_get_child (GTK_BIN (tab))));
 	if (attr)
 		pango_attr_list_ref (attr);
 
 	gtk_button_set_label (GTK_BUTTON (tab), name);
-	gtk_widget_queue_resize (tab->parent->parent->parent);
+	gtk_widget_queue_resize (gtk_widget_get_parent(gtk_widget_get_parent(gtk_widget_get_parent(tab))));
 
 	if (attr)
 	{
-		gtk_label_set_attributes (GTK_LABEL (GTK_BIN (tab)->child), attr);
+		gtk_label_set_attributes (GTK_LABEL (gtk_bin_get_child (GTK_BIN (tab))), attr);
 		pango_attr_list_unref (attr);
 	}
 }
