@@ -151,7 +151,7 @@ void
 fe_tray_set_tooltip (const char *text)
 {
 	if (sticon)
-		gtk_status_icon_set_tooltip (sticon, text);
+		gtk_status_icon_set_tooltip_text (sticon, text);
 }
 
 void
@@ -408,6 +408,7 @@ tray_toggle_visibility (gboolean force_hide)
 	static int x, y;
 	static GdkScreen *screen;
 	static int maximized;
+	static int fullscreen;
 	GtkWindow *win;
 
 	if (!sticon)
@@ -431,6 +432,7 @@ tray_toggle_visibility (gboolean force_hide)
 		gtk_window_get_position (win, &x, &y);
 		screen = gtk_window_get_screen (win);
 		maximized = prefs.hex_gui_win_state;
+		fullscreen = prefs.hex_gui_win_fullscreen;
 		gtk_widget_hide (GTK_WIDGET (win));
 	}
 	else
@@ -441,6 +443,8 @@ tray_toggle_visibility (gboolean force_hide)
 		gtk_window_move (win, x, y);
 		if (maximized)
 			gtk_window_maximize (win);
+		if (fullscreen)
+			gtk_window_fullscreen (win);
 		gtk_widget_show (GTK_WIDGET (win));
 		gtk_window_present (win);
 	}
@@ -551,7 +555,7 @@ tray_make_item (GtkWidget *menu, char *label, void *callback, void *userdata)
 static void
 tray_toggle_cb (GtkCheckMenuItem *item, unsigned int *setting)
 {
-	*setting = item->active;
+	*setting = gtk_check_menu_item_get_active (item);
 }
 
 static void
@@ -754,19 +758,22 @@ tray_priv (char *from, char *text)
 	if (alert_match_word (from, prefs.hex_irc_no_hilight))
 		return;
 
-	tray_set_flash (ICON_MSG);
-
 	network = hexchat_get_info (ph, "network");
 	if (!network)
 		network = hexchat_get_info (ph, "server");
 
-	tray_priv_count++;
-	if (tray_priv_count == 1)
-		tray_set_tipf (_(DISPLAY_NAME": Private message from: %s (%s)"),
-							from, network);
-	else
-		tray_set_tipf (_(DISPLAY_NAME": %u private messages, latest from: %s (%s)"),
-							tray_priv_count, from, network);
+	if (prefs.hex_input_tray_priv)
+	{
+		tray_set_flash (ICON_MSG);
+
+		tray_priv_count++;
+		if (tray_priv_count == 1)
+			tray_set_tipf (_(DISPLAY_NAME": Private message from: %s (%s)"),
+								from, network);
+		else
+			tray_set_tipf (_(DISPLAY_NAME": %u private messages, latest from: %s (%s)"),
+								tray_priv_count, from, network);
+	}
 
 	if (prefs.hex_input_balloon_priv)
 		tray_set_balloonf (text, _("Private message from: %s (%s)"),
@@ -776,11 +783,7 @@ tray_priv (char *from, char *text)
 static int
 tray_priv_cb (char *word[], void *userdata)
 {
-	/*if (tray_status == TS_HIGHLIGHT)
-		return HEXCHAT_EAT_NONE;*/
-
-	if (prefs.hex_input_tray_priv)
-		tray_priv (word[1], word[2]);
+	tray_priv (word[1], word[2]);
 
 	return HEXCHAT_EAT_NONE;
 }
@@ -788,10 +791,7 @@ tray_priv_cb (char *word[], void *userdata)
 static int
 tray_invited_cb (char *word[], void *userdata)
 {
-	/*if (tray_status == TS_HIGHLIGHT)
-		return HEXCHAT_EAT_NONE;*/
-
-	if (prefs.hex_input_tray_priv && (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1))
+	if (!prefs.hex_away_omit_alerts || tray_find_away_status () != 1)
 		tray_priv (word[2], "Invited");
 
 	return HEXCHAT_EAT_NONE;
@@ -884,6 +884,8 @@ tray_plugin_init (hexchat_plugin *plugin_handle, char **plugin_name,
 
 	hexchat_hook_print (ph, "Private Message", -1, tray_priv_cb, NULL);
 	hexchat_hook_print (ph, "Private Message to Dialog", -1, tray_priv_cb, NULL);
+	hexchat_hook_print (ph, "Private Action", -1, tray_priv_cb, NULL);
+	hexchat_hook_print (ph, "Private Action to Dialog", -1, tray_priv_cb, NULL);
 	hexchat_hook_print (ph, "Notice", -1, tray_priv_cb, NULL);
 	hexchat_hook_print (ph, "Invited", -1, tray_invited_cb, NULL);
 
